@@ -470,8 +470,9 @@ void	CGUI::OnOpenLoadPage(short whichPage)
 	currentMainScreen->PaintRect(gGUIConst->kUserMenuPosX, gGUIConst->kUserMenuPosY, gGUIConst->kUserMenuPosX + gGUIConst->kUserMenuWidth, gGUIConst->kUserMenuPosY + gGUIConst->kUserMenuHeight, kBlackColor, kShapemodusTransparent2);
 
 	for (n = 0; n < kNumOfSaveGameSlots; n ++) {
-		char *filename;
-		gLevel->GetSavedGameTitle(gSystem->QualifyHomeDir(gGUIConst->kSavedGames[n]), sgTitles[n]);  // by LL
+		char *filename = gSystem->QualifyHomeDir(gGUIConst->kSavedGames[n]);
+		gLevel->GetSavedGameTitle(filename, sgTitles[n]);  // by LL
+		delete [] filename;
 	}
 
 	if (whichPage == kSaveGamePage) 
